| metaComm-class | R Documentation |
An S4 class to specify the state of a metacommunity
metaComm(spAbund, spTrait)
spAbund |
spAbund |
spTrait |
spTrait |
spAbunda numeric vector of the relative abundances for each species in the meta community
spTraita numeric vector of the average trait value for each species in the meta community
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.