| rolePhylo-class | R Documentation |
An S4 class to specify a phylogeny for the purpose of the RoLE model.
rolePhylo(n, e, l, alive, tipNames, scale)
n |
The number of tips in the phylogeny |
e |
The numeric edge matrix of the phylogeny. Each row contains an ancestor-child pair where the 1st column is the ancestor and the 2nd is the child |
l |
A numeric vector of edge lengths. The units of l are the time steps (iterations) of the model. Each time step unit is equal to 1/J generations where J is the number of individuals in the local community |
alive |
A logical vector indicating whether each tip is extant or not. |
tipNames |
A character vector of the tip names. |
scale |
A single numeric value of time scale translation to years. |
A 'rolePhylo' object.
nThe number of tips in the phylogeny
eThe numeric edge matrix of the phylogeny. Each row contains an ancestor-child pair where the 1st column is the ancestor and the 2nd is the child
lA numeric vector of edge lengths. The units of l are the time steps (iterations) of the model. Each time step unit is equal to 1/J generations where J is the number of individuals in the local community
aliveA logical vector indicating whether each tip is extant or not.
tipNamesA character vector of the tip names.
scaleA single numeric value of time scale translation to years.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.